Product class

Constructors

Product({required int id, required String name, required String description, String? beforeMoneyAmount, required num moneyAmount, double? taxCoeff, required String creditAmount, DateTime? createdAt, DateTime? updatedAt, DateTime? deletedAt})
Returns a new Product instance.

Properties

beforeMoneyAmount String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
createdAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
creditAmount String
getter/setter pair
deletedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int
getter/setter pair
moneyAmount num
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxCoeff double?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
updatedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Product?
Returns a new Product instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Product>?
mapFromJson(dynamic json) Map<String, Product>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Product>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.