ProductApi class

Constructors

ProductApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buyProduct(String id, {BuyProductRequestBody? buyProductRequestBody}) Future<SuccessResponse?>
Buys a product
buyProductWithHttpInfo(String id, {BuyProductRequestBody? buyProductRequestBody}) Future<Response>
Buys a product
listProducts() Future<List<Product>?>
Get all products
listProductsWithHttpInfo() Future<Response>
Get all products
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited