Transaction class

Constructors

Transaction({required String id, required String creditAmount, required String currentDate, String? filePath, required String createdAt, TransactionRtr? rtr})
Returns a new Transaction instance.

Properties

createdAt String
getter/setter pair
creditAmount String
getter/setter pair
currentDate String
getter/setter pair
filePath String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
getter/setter pair
rtr TransactionRtr?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Transaction?
Returns a new Transaction instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Transaction>?
mapFromJson(dynamic json) Map<String, Transaction>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Transaction>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.