WalletApi class

Constructors

WalletApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBalance() Future<Balance?>
Get balance of wallet
getBalanceWithHttpInfo() Future<Response>
Get balance of wallet
getWallet() Future<Wallet?>
Returns a wallet
getWalletWithHttpInfo() Future<Response>
Returns a wallet
listTransactions({DateTime? from, DateTime? to, String? orderByAttribute, String? orderByType}) Future<List<Transaction>?>
Get all transactions of a wallet
listTransactionsWithHttpInfo({DateTime? from, DateTime? to, String? orderByAttribute, String? orderByType}) Future<Response>
Get all transactions of a wallet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited